==> haskell-monad-journal-0.8.1-271-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-journal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 monad-journal
version:              0.8.1
visibility:           public
id:                   monad-journal-0.8.1-EMYgL1qN1WLJgCJY0oo9Nx
key:                  monad-journal-0.8.1-EMYgL1qN1WLJgCJY0oo9Nx
license:              BSD-3-Clause
maintainer:           Dimitri Sabadie <dimitri.sabadie@gmail.com>
author:               Dimitri Sabadie <dimitri.sabadie@gmail.com>
homepage:             http://github.com/phaazon/monad-journal
synopsis:             Pure logger typeclass and monad transformer
description:
    This package provides a typeclass for logging in
    pure code, or more generally, in any kind of
    context. You can do whatever you want with
    logs, especially get them, clear them or even
    sink them through '\''IO'\'' if you'\''re logging in
    @(MonadIO m) => m@.

category:             Control
abi:                  d17b16455fc66b8c47e834de613376b8
exposed:              True
exposed-modules:
    Control.Monad.Journal Control.Monad.Journal.Class
    Control.Monad.Trans.Journal

import-dirs:          /usr/lib/ghc-9.2.8/site-local/monad-journal-0.8.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/monad-journal-0.8.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-monad-journal
hs-libraries:         HSmonad-journal-0.8.1-EMYgL1qN1WLJgCJY0oo9Nx
depends:
    base-4.16.4.0 monad-control-1.0.3.1-I8GZevPHGG9CaaoPHICfGK
    mtl-2.2.2 transformers-0.5.6.2
    transformers-base-0.4.6-L226RdjYZ7s6DhRd0WmCwN

haddock-interfaces:
    /usr/share/doc/haskell-monad-journal/html/monad-journal.haddock

haddock-html:         /usr/share/doc/haskell-monad-journal/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-journal-0.8.1-299.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-journal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 monad-journal
version:              0.8.1
visibility:           public
id:                   monad-journal-0.8.1-9NsrtbCBkBFJQpGXDWyCGA
key:                  monad-journal-0.8.1-9NsrtbCBkBFJQpGXDWyCGA
license:              BSD-3-Clause
maintainer:           Dimitri Sabadie <dimitri.sabadie@gmail.com>
author:               Dimitri Sabadie <dimitri.sabadie@gmail.com>
homepage:             http://github.com/phaazon/monad-journal
synopsis:             Pure logger typeclass and monad transformer
description:
    This package provides a typeclass for logging in
    pure code, or more generally, in any kind of
    context. You can do whatever you want with
    logs, especially get them, clear them or even
    sink them through '\''IO'\'' if you'\''re logging in
    @(MonadIO m) => m@.

category:             Control
abi:                  4edb00f1f22502155126ef612206484a
exposed:              True
exposed-modules:
    Control.Monad.Journal Control.Monad.Journal.Class
    Control.Monad.Trans.Journal

import-dirs:          /usr/lib/ghc-9.4.8/site-local/monad-journal-0.8.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/monad-journal-0.8.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/monad-journal-0.8.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-monad-journal
hs-libraries:         HSmonad-journal-0.8.1-9NsrtbCBkBFJQpGXDWyCGA
depends:
    base-4.17.2.1 monad-control-1.0.3.1-CU0oSebqH0K53geyhZCKTM
    mtl-2.2.2 transformers-0.5.6.2
    transformers-base-0.4.6-Gpx2WMc051hBRdn2HnKilA

haddock-interfaces:
    /usr/share/doc/haskell-monad-journal/html/monad-journal.haddock

haddock-html:         /usr/share/doc/haskell-monad-journal/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
